==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterManagerListBuilder extends ClusterManagerListFluentImpl<ClusterManagerListBuilder> implements VisitableBuilder<ClusterManagerList,ClusterManagerListBuilder>{
  public ClusterManagerListBuilder() {
    this(false);
  }
  public ClusterManagerListBuilder(Boolean validationEnabled) {
    this(new ClusterManagerList(), validationEnabled);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterManagerList(), validationEnabled);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,ClusterManagerList instance) {
    this(fluent, instance, false);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,ClusterManagerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterManagerListBuilder(ClusterManagerList instance) {
    this(instance,false);
  }
  public ClusterManagerListBuilder(ClusterManagerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterManagerListFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterManagerList build() {
    ClusterManagerList buildable = new ClusterManagerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterManagerListBuilder extends ClusterManagerListFluent<ClusterManagerListBuilder> implements VisitableBuilder<ClusterManagerList,ClusterManagerListBuilder>{
  public ClusterManagerListBuilder() {
    this(false);
  }
  public ClusterManagerListBuilder(Boolean validationEnabled) {
    this(new ClusterManagerList(), validationEnabled);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterManagerList(), validationEnabled);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,ClusterManagerList instance) {
    this(fluent, instance, false);
  }
  public ClusterManagerListBuilder(ClusterManagerListFluent<?> fluent,ClusterManagerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterManagerList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterManagerListBuilder(ClusterManagerList instance) {
    this(instance,false);
  }
  public ClusterManagerListBuilder(ClusterManagerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterManagerList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterManagerListFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterManagerList build() {
    ClusterManagerList buildable = new ClusterManagerList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
